@@ -6,7 +6,7 @@
               IT8712F  Super I/O chip w/LPC interface & SMBus
               SiS950   A clone of the IT8705F
 
-    Copyright (c) 2001 Chris Gauthron <chrisg@0-in.com> 
+    Copyright (c) 2001 Chris Gauthron
     Largely inspired by lm78.c of the same package
 
     This program is free software; you can redistribute it and/or modify
@@ -333,6 +333,8 @@ static struct i2c_driver it87_driver = {
 #define IT87_ALARM_FAN1 0x0001
 #define IT87_ALARM_FAN2 0x0002
 #define IT87_ALARM_FAN3 0x0004
+#define IT87_ALARM_FAN4 0x0008
+#define IT87_ALARM_FAN5 0x0040
 #define IT87_ALARM_TEMP1 0x00010000
 #define IT87_ALARM_TEMP2 0x00020000
 #define IT87_ALARM_TEMP3 0x00040000
@@ -549,7 +551,7 @@ static int it87_detect(struct i2c_adapter *adapter, int address,
 		client_name = "IT8712 chip";
 	} else {
 #ifdef DEBUG
-		printk("it87.o: Internal error: unknown kind (%d)?!?",
+		printk("it87.o: Internal error: unknown kind (%d)\n",
 		       kind);
 #endif
 		goto ERROR1;
@@ -1119,7 +1121,7 @@ static void __exit sm_it87_exit(void)
 }
 
 
-MODULE_AUTHOR("Chris Gauthron <chrisg@0-in.com>");
+MODULE_AUTHOR("Chris Gauthron");
 MODULE_DESCRIPTION("IT8705F, IT8712F, Sis950 driver");
 MODULE_PARM(update_vbat, "i");
 MODULE_PARM_DESC(update_vbat, "Update vbat if set else return powerup value");
