@@ -303,7 +303,7 @@ struct lm93_data {
 	u16 block5[4];
 
 	/* block6 has a lot of data we don't need */
-	struct { u8 min; u8 max; } temp_lim[3];
+	struct { u8 min; u8 max; } temp_lim[4];
 
 	/* vin1 - vin16: low and high limits */
 	struct { u8 min; u8 max; } block7[16];
@@ -1109,7 +1109,7 @@ static void lm93_prochot(struct i2c_client *client, int operation,
 	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm93_update_client(client);
 		results[0] = data->prochot_max[nr];
-		results[1] = data->block4[nr].avg;
+		results[1] = data->block4[nr].cur;
 		results[2] = data->block4[nr].avg;
 		*nrels_mag = 3;
 	} else if (operation == SENSORS_PROC_REAL_WRITE) {
