@@ -547,6 +547,82 @@ static const ChipDescriptor lm80_chip = {
   lm80_names, lm80_features, SENSORS_LM80_ALARMS, 0
 };
 
+/** LM85 **/
+
+static const char *lm85_names[] = {
+  SENSORS_LM85_PREFIX, SENSORS_LM85B_PREFIX, SENSORS_LM85C_PREFIX,
+  SENSORS_ADM1027_PREFIX, SENSORS_ADT7463_PREFIX,
+  SENSORS_EMC6D100_PREFIX, SENSORS_EMC6D102_PREFIX, NULL
+};
+
+static const FeatureDescriptor lm85_features[] = {
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN0, 0,
+    { SENSORS_LM85_IN0, SENSORS_LM85_IN0_MIN, SENSORS_LM85_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN1, 0,
+    { SENSORS_LM85_IN1, SENSORS_LM85_IN1_MIN, SENSORS_LM85_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN2, 0,
+    { SENSORS_LM85_IN2, SENSORS_LM85_IN2_MIN, SENSORS_LM85_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN3, 0,
+    { SENSORS_LM85_IN3, SENSORS_LM85_IN3_MIN, SENSORS_LM85_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM85_ALARM_IN4, 0,
+    { SENSORS_LM85_IN4, SENSORS_LM85_IN4_MIN, SENSORS_LM85_IN4_MAX, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN1, 0,
+    { SENSORS_LM85_FAN1, SENSORS_LM85_FAN1_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN2, 0,
+    { SENSORS_LM85_FAN2, SENSORS_LM85_FAN2_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN3, 0,
+    { SENSORS_LM85_FAN3, SENSORS_LM85_FAN3_MIN, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, LM85_ALARM_FAN4, 0,
+    { SENSORS_LM85_FAN4, SENSORS_LM85_FAN4_MIN, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP1, 0,
+    { SENSORS_LM85_TEMP1, SENSORS_LM85_TEMP1_MIN, SENSORS_LM85_TEMP1_MAX, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP2, 0,
+    { SENSORS_LM85_TEMP2, SENSORS_LM85_TEMP2_MIN, SENSORS_LM85_TEMP2_MAX, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM85_ALARM_TEMP3, 0,
+    { SENSORS_LM85_TEMP3, SENSORS_LM85_TEMP3_MIN, SENSORS_LM85_TEMP3_MAX, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor lm85_chip = {
+  lm85_names, lm85_features, SENSORS_LM85_ALARMS, 0
+};
+
+/** LM87 **/
+
+static const char *lm87_names[] = {
+  SENSORS_LM87_PREFIX, NULL
+};
+
+static const FeatureDescriptor lm87_features[] = {
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN0, 0,
+    { SENSORS_LM87_IN0, SENSORS_LM87_IN0_MIN, SENSORS_LM87_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN1, 0,
+    { SENSORS_LM87_IN1, SENSORS_LM87_IN1_MIN, SENSORS_LM87_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN2, 0,
+    { SENSORS_LM87_IN2, SENSORS_LM87_IN2_MIN, SENSORS_LM87_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN3, 0,
+    { SENSORS_LM87_IN3, SENSORS_LM87_IN3_MIN, SENSORS_LM87_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN4, 0,
+    { SENSORS_LM87_IN4, SENSORS_LM87_IN4_MIN, SENSORS_LM87_IN4_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN5, 0,
+    { SENSORS_LM87_IN5, SENSORS_LM87_IN5_MIN, SENSORS_LM87_IN5_MAX, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, LM87_ALARM_FAN1, 0,
+    { SENSORS_LM87_FAN1, SENSORS_LM87_FAN1_MIN, SENSORS_LM87_FAN1_DIV, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, LM87_ALARM_FAN2, 0,
+    { SENSORS_LM87_FAN2, SENSORS_LM87_FAN2_MIN, SENSORS_LM87_FAN2_DIV, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP1, 0,
+    { SENSORS_LM87_TEMP1, SENSORS_LM87_TEMP1_HYST, SENSORS_LM87_TEMP1_OVER, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP2, 0,
+    { SENSORS_LM87_TEMP2, SENSORS_LM87_TEMP2_HYST, SENSORS_LM87_TEMP2_OVER, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP3, 0,
+    { SENSORS_LM87_TEMP3, SENSORS_LM87_TEMP3_HYST, SENSORS_LM87_TEMP3_OVER, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor lm87_chip = {
+  lm87_names, lm87_features, SENSORS_LM87_ALARMS, 0
+};
+
 /** IT87 (thanks to Mike Black) **/
 
 static const char *it87_names[] = {
@@ -1106,21 +1182,21 @@ static const char *pc87427_names[] = {
 
 static const FeatureDescriptor pc87427_features[] = {
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(1), SENSORS_PC87427_FAN_MIN(1), -1, -1 } },
+    { SENSORS_PC87427_FAN(1), SENSORS_PC87427_FAN_MIN(1), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(2), SENSORS_PC87427_FAN_MIN(2), -1, -1 } },
+    { SENSORS_PC87427_FAN(2), SENSORS_PC87427_FAN_MIN(2), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(3), SENSORS_PC87427_FAN_MIN(3), -1, -1 } },
+    { SENSORS_PC87427_FAN(3), SENSORS_PC87427_FAN_MIN(3), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(4), SENSORS_PC87427_FAN_MIN(4), -1, -1 } },
+    { SENSORS_PC87427_FAN(4), SENSORS_PC87427_FAN_MIN(4), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(5), SENSORS_PC87427_FAN_MIN(5), -1, -1 } },
+    { SENSORS_PC87427_FAN(5), SENSORS_PC87427_FAN_MIN(5), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(6), SENSORS_PC87427_FAN_MIN(6), -1, -1 } },
+    { SENSORS_PC87427_FAN(6), SENSORS_PC87427_FAN_MIN(6), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(7), SENSORS_PC87427_FAN_MIN(7), -1, -1 } },
+    { SENSORS_PC87427_FAN(7), SENSORS_PC87427_FAN_MIN(7), -1 } },
   { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_PC87427_FAN(8), SENSORS_PC87427_FAN_MIN(8), -1, -1 } },
+    { SENSORS_PC87427_FAN(8), SENSORS_PC87427_FAN_MIN(8), -1 } },
   { NULL }
 };
 
@@ -1203,12 +1279,12 @@ static const FeatureDescriptor f71805f_features[] = {
     { SENSORS_F71805F_IN(7), SENSORS_F71805F_IN_MIN(7), SENSORS_F71805F_IN_MAX(7), -1 } },
   { fmtVolts_2, rrdF3, DataType_voltage, 0, 0,
     { SENSORS_F71805F_IN(8), SENSORS_F71805F_IN_MIN(8), SENSORS_F71805F_IN_MAX(8), -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(1), SENSORS_F71805F_FAN_MIN(1), -1, -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(2), SENSORS_F71805F_FAN_MIN(2), -1, -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(3), SENSORS_F71805F_FAN_MIN(3), -1, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(1), SENSORS_F71805F_FAN_MIN(1), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(2), SENSORS_F71805F_FAN_MIN(2), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(3), SENSORS_F71805F_FAN_MIN(3), -1 } },
   { fmtTemps_0, rrdF0, DataType_temperature, 1 << 0, 0,
     { SENSORS_F71805F_TEMP(1), SENSORS_F71805F_TEMP_MAX(1), SENSORS_F71805F_TEMP_HYST(1), -1 } },
   { fmtTemps_0, rrdF0, DataType_temperature, 1 << 1, 0,
@@ -1285,6 +1361,80 @@ static const ChipDescriptor k8temp_chip = {
   k8temp_names, k8temp_features, 0, 0
 };
 
+/** W83793 **/
+
+static const char *w83793_names[] = {
+  SENSORS_W83793_PREFIX, NULL
+};
+
+static const FeatureDescriptor w83793_features[] = {
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(1), SENSORS_W83793_FAN_MIN(1), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(2), SENSORS_W83793_FAN_MIN(2), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(3), SENSORS_W83793_FAN_MIN(3), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(4), SENSORS_W83793_FAN_MIN(4), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(5), SENSORS_W83793_FAN_MIN(5), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(6), SENSORS_W83793_FAN_MIN(6), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(7), SENSORS_W83793_FAN_MIN(7), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(8), SENSORS_W83793_FAN_MIN(8), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(9), SENSORS_W83793_FAN_MIN(9), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(10), SENSORS_W83793_FAN_MIN(10), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(11), SENSORS_W83793_FAN_MIN(11), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(12), SENSORS_W83793_FAN_MIN(12), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(1), SENSORS_W83793_TEMP_CRIT(1), SENSORS_W83793_TEMP_CRIT_HYST(1), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(2), SENSORS_W83793_TEMP_CRIT(2), SENSORS_W83793_TEMP_CRIT_HYST(2), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(3), SENSORS_W83793_TEMP_CRIT(3), SENSORS_W83793_TEMP_CRIT_HYST(3), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(4), SENSORS_W83793_TEMP_CRIT(4), SENSORS_W83793_TEMP_CRIT_HYST(4), -1 } },
+  { fmtTemps_0, rrdF0, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(5), SENSORS_W83793_TEMP_CRIT(5), SENSORS_W83793_TEMP_CRIT_HYST(5), -1 } },
+  { fmtTemps_0, rrdF0, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(6), SENSORS_W83793_TEMP_CRIT(6), SENSORS_W83793_TEMP_CRIT_HYST(6), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(0), SENSORS_W83793_IN_MIN(0), SENSORS_W83793_IN_MAX(0), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(1), SENSORS_W83793_IN_MIN(1), SENSORS_W83793_IN_MAX(1), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(2), SENSORS_W83793_IN_MIN(2), SENSORS_W83793_IN_MAX(2), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(3), SENSORS_W83793_IN_MIN(3), SENSORS_W83793_IN_MAX(3), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(4), SENSORS_W83793_IN_MIN(4), SENSORS_W83793_IN_MAX(4), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(5), SENSORS_W83793_IN_MIN(5), SENSORS_W83793_IN_MAX(5), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(6), SENSORS_W83793_IN_MIN(6), SENSORS_W83793_IN_MAX(6), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(7), SENSORS_W83793_IN_MIN(7), SENSORS_W83793_IN_MAX(7), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(8), SENSORS_W83793_IN_MIN(8), SENSORS_W83793_IN_MAX(8), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(9), SENSORS_W83793_IN_MIN(9), SENSORS_W83793_IN_MAX(9), -1 } },
+  { fmtVolt_3, rrdF3, DataType_voltage, 0, 0,
+    { SENSORS_W83793_VID0, -1 } },
+  { fmtVolt_3, rrdF3, DataType_voltage, 0, 0,
+    { SENSORS_W83793_VID1, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor w83793_chip = {
+  w83793_names, w83793_features, 0, 0
+};
+
 
 /** ALL **/
 
@@ -1297,6 +1447,8 @@ const ChipDescriptor * const knownChips[] = {
   &lm75_chip,
   &lm78_chip,
   &lm80_chip,
+  &lm85_chip,
+  &lm87_chip,
   &max1617_chip,
   &maxilife_chip,
   &sis5595_chip,
@@ -1314,5 +1466,6 @@ const ChipDescriptor * const knownChips[] = {
   &f71805f_chip,
   &vt1211_chip,
   &k8temp_chip,
+  &w83793_chip,
   NULL
 };
